<?php 
 /**
  * 
  * @package    BizReview - Business and google Place Review WordPress Plugin
  * @version    1.0
  * @author     ThemeAtelier
  * @Websites: https://themeatelier.net/
  *
  */
  
// Blocking direct access
if( ! defined( 'ABSPATH' ) ) {
    die ( BIZREVIEW_ALERT_MSG );
}

/**************************************
*Creating Widget
***************************************/
 
class bizreview_custom_widget extends WP_Widget {


function __construct() {

parent::__construct(
// Base ID of your widget
'bizreview_custom_review_widget', 


// Widget name will appear in UI
esc_html__( 'Custom Review [BizReview]', 'bizreview' ), 

// Widget description
array( 'description' => esc_html__( 'Add custom review widget.', 'bizreview' ), ) 
);

}

// This is where the action happens
public function widget( $args, $instance ) {
$title 		= apply_filters( 'widget_title', $instance['title'] );
$cat 		= apply_filters( 'widget_cat', $instance['cat'] );
$max_limit 	= apply_filters( 'widget_maxrows', $instance['max_limit'] );

// before and after widget arguments are defined by themes
echo wp_kses_post( $args['before_widget'] );
if ( ! empty( $title ) )
echo wp_kses_post( $args['before_title'] . $title . $args['after_title'] );

echo '<div class="review-widget-wrapper">';


$reviewArgs = array(
		'post_type' => 'bizreview',
		'posts_per_page' => $max_limit,
		'tax_query' => array(
		'relation' => 'IN',
			array(
			'taxonomy' => 'review_category',
			'field' => 'slug',
			'terms' => $cat
			)
		)
     );

$query = new WP_Query( $reviewArgs );
if( $query->have_posts() ):
	while( $query->have_posts() ):
		$query->the_post();

		$postId  = get_the_id();

		$name       = get_post_meta( $postId, 'bizreviewreviewer_name', true );
        $url     	= get_post_meta( $postId, 'bizreviewreviewe_url', true );
        $type       = get_post_meta( $postId, 'bizreviewreviewe_type', true );
        $pic     	= get_post_meta( $postId, 'bizreviewreviewer_pic', true );
        $date       = get_post_meta( $postId, 'bizreviewreviewer_date', true );
        $rating  	= get_post_meta( $postId, 'bizreviewreview_rating', true );
        $platform   = get_post_meta( $postId, 'bizreviewreview_platform', true );
        $reviewContent    = get_post_meta( $postId, 'bizreviewcontent', true );

        $img = wp_get_attachment_image_src( $pic, 'full' );

?>
<div class="bizr-google-review-inner single-wreview-item p-15px-lr p-30px-t p-30px-b">
	<div class="bizr-google--top">
		<?php 
		if( !empty( $img[0] ) ):
		?>
		<div class="bizr-google--reviewer-img">
			<div class="review-platform">
				<?php
					if( $platform == 'google' ) {
						echo '<i class="fab color-google fa-google"></i>';
					} else if( $platform == 'facebook' ) {
						echo '<i class="fab color-fb fa-facebook"></i>';
					} else if ( $platform == 'yelp' ) {
						echo '<i class="fab color-yelp fa-yelp"></i>'; 
					}
				?>
			</div>
			<img src="<?php echo esc_url( $img[0] ); ?>" alt="<?php echo esc_attr( $name ); ?>">
			<?php
			if( !empty( $name ) ):
			?>
			<p class="bizr-google--reviewer-name"><strong><?php echo esc_html( $name ); ?></strong></p>
			<?php 
			endif;
			?>
		</div>
		<?php 
		endif;
		?>
		<div class="bizr-google--details">
			<div class="bizr-google--times">
				<?php echo esc_html( $date ).' '.__( 'via Google', 'bizreview' ); ?>
			</div>
			<div class="bizr-google--rating">
				<?php bizreview_star_review( $rating ); ?>
			</div>
			<?php 
			if( !empty( $reviewContent ) ):
			?>
			<div class="bizr-google--content">
				<p><?php echo esc_html( $reviewContent ); ?></p>
			</div>
			<?php 
			endif;
			?>
		</div>
	</div>
</div>
	<?php 
	endwhile;
endif;
echo '</div>';
echo wp_kses_post( $args['after_widget'] );
}
		
// Widget Backend 
public function form( $instance ) {
	
if ( isset( $instance[ 'title' ] ) ) {
	$title = $instance[ 'title' ];
}else {
	$title = esc_html__( 'Custom Review', 'bizreview' );
}

// Minimum rating
if ( isset( $instance[ 'cat' ] ) ) {
	$cat = $instance[ 'cat' ];
}else {
	$cat = '';
}
//Max Reviews
if ( isset( $instance[ 'max_limit' ] ) ) {
	$max_limit = $instance[ 'max_limit' ];
}else {
	$max_limit = '5';
}


// Widget admin form
?>
<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:' ,'bizreview'); ?></label> 
<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'cat' ) ); ?>"><?php esc_html_e( 'Category:' ,'bizreview'); ?></label> 
<select id="<?php echo esc_attr( $this->get_field_id( 'cat' ) ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>">
	<?php 
	$cats = bizreview_custom_review_cat();
	foreach( $cats as $key => $catname ) {
		echo '<option value="'.esc_attr( $key ).'" '.selected( $key, $cat ).'>'.esc_attr( $catname ).'</option>';
	}
	?>
</select>
</p>
<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'max_limit' ) ); ?>"><?php esc_html_e( 'Max Limit:' ,'bizreview'); ?></label>
<select id="<?php echo esc_attr( $this->get_field_id( 'max_limit' ) ); ?>" name="<?php echo $this->get_field_name( 'max_limit' ); ?>">
	<option value="1" <?php selected( $max_limit, '1' ); ?>><?php esc_html_e( '1', 'bizreview' ); ?></option>
	<option value="2" <?php selected( $max_limit, '2' ); ?>><?php esc_html_e( '2', 'bizreview' ); ?></option>
	<option value="3" <?php selected( $max_limit, '3' ); ?>><?php esc_html_e( '3', 'bizreview' ); ?></option>
	<option value="4" <?php selected( $max_limit, '4' ); ?>><?php esc_html_e( '4', 'bizreview' ); ?></option>
	<option value="5" <?php selected( $max_limit, '5' ); ?>><?php esc_html_e( '5', 'bizreview' ); ?></option>
	<option value="6" <?php selected( $max_limit, '6' ); ?>><?php esc_html_e( '6', 'bizreview' ); ?></option>
	<option value="7" <?php selected( $max_limit, '7' ); ?>><?php esc_html_e( '7', 'bizreview' ); ?></option>
	<option value="8" <?php selected( $max_limit, '8' ); ?>><?php esc_html_e( '8', 'bizreview' ); ?></option>
	<option value="9" <?php selected( $max_limit, '9' ); ?>><?php esc_html_e( '9', 'bizreview' ); ?></option>
	<option value="10" <?php selected( $max_limit, '10' ); ?>><?php esc_html_e( '10', 'bizreview' ); ?></option>
</select>



</p>

<?php 
}

	
// Updating widget replacing old instances with new
public function update( $new_instance, $old_instance ) {
	
	
$instance = array();
$instance['title'] 	  	= ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
$instance['cat']  		= ( ! empty( $new_instance['cat'] ) ) ? strip_tags( $new_instance['cat'] ) : '';
$instance['max_limit']  	= ( ! empty( $new_instance['max_limit'] ) ) ? strip_tags( $new_instance['max_limit'] ) : '';

return $instance;
}
} // Class  ends here


// Register and load the widget
function bizreview_custom_init_widget() {
	register_widget( 'bizreview_custom_widget' );
}
add_action( 'widgets_init', 'bizreview_custom_init_widget' );
	

?>